@@ -5,6 +5,7 @@
 
 from collections.abc import MutableMapping
 import logging
+import pprint  # noqa: F401
 
 from .cif import CIFMixin
 from .configuration import _Configuration
@@ -332,7 +333,7 @@ class _System(CIFMixin, MutableMapping):
         periodicity=0,
         coordinatesystem=None,
         symmetry=None,
-        cell=None,
+        cell_id=None,
         atomset=None,
         bondset=None,
         make_current=True,
@@ -350,8 +351,8 @@ class _System(CIFMixin, MutableMapping):
             Defaults to Cartesian for molecules and fractional for crystals.
         symmetry : int or str = None
             The id or name of the point or space group (optional)
-        cell : Cell or 6-vector = None
-            The cell parameters, default to last ones.
+        cell_id : int = None
+            The id of the _Cell object
         atomset : int = None
             The set of atoms in this configurationn
         bondset : int = None
@@ -377,19 +378,31 @@ class _System(CIFMixin, MutableMapping):
                     kwargs["coordinatesystem"] = "fractional"
         if symmetry is not None:
             kwargs["symmetry"] = symmetry
-        if cell is not None:
-            kwargs["cell"] = cell
+        if cell_id is not None:
+            kwargs["cell"] = cell_id
         if atomset is not None:
             kwargs["atomset"] = atomset
         if bondset is not None:
             kwargs["bondset"] = bondset
 
         cid = self["configuration"].append(system=self.id, **kwargs)[0]
+        configuration = _Configuration(_id=cid, system_db=self.system_db)
+
+        # If the atomset was given, need to create dummy coordinates
+        if atomset is not None:
+            n_atoms = configuration.n_atoms
+            data = {"configuration": configuration.id}
+            data["atom"] = configuration.atoms.ids
+            data["x"] = [0.0] * n_atoms
+            data["y"] = [0.0] * n_atoms
+            data["z"] = [0.0] * n_atoms
+            table = _Table(self.system_db, "coordinates")
+            table.append(n=n_atoms, **data)
 
         if make_current:
             self._current_configuration_id = cid
 
-        return _Configuration(_id=cid, system_db=self.system_db)
+        return configuration
 
     def create_table(self, name, cls=_Table, other=None):
         """Create a new table with the given name.
