@@ -10,6 +10,7 @@ import sqlite3
 import molsystem
 from .cif import CIFMixin
 from .configuration import _Configuration
+from .properties import _Properties
 from .system import _System
 from .table import _Table
 from .templates import _Templates
@@ -374,6 +375,11 @@ class SystemDB(CIFMixin, collections.abc.MutableMapping):
         """The parent of this, i.e. a Systems object."""
         return self._parent
 
+    @property
+    def properties(self):
+        """The class to handle the properties."""
+        return _Properties(self)
+
     @property
     def system(self):
         """The current system object."""
@@ -607,6 +613,46 @@ class SystemDB(CIFMixin, collections.abc.MutableMapping):
 
         return result
 
+    def find_configurations(self, atomset=None, bondset=None):
+        """Return the configurations that have given atom- or bondsets
+
+        Parameters
+        ----------
+        atomset : int = None
+            The id of the atomset.
+        bondset : int = None
+            The id of the bondset.
+
+        Returns
+        -------
+        [_Configuration]
+        """
+
+        if atomset is not None:
+            if bondset is not None:
+                self.cursor.execute(
+                    "SELECT id FROM configuration WHERE atomset = ? AND bondset = ?",
+                    (atomset, bondset),
+                )
+            else:
+                self.cursor.execute(
+                    "SELECT id FROM configuration WHERE atomset = ?", (atomset,)
+                )
+            return [
+                _Configuration(_id=cid, system_db=self)
+                for cid in self.cursor.fetchall()
+            ]
+        elif bondset is not None:
+            self.cursor.execute(
+                "SELECT id FROM configuration WHERE bondset = ?", (bondset,)
+            )
+            return [
+                _Configuration(_id=cid, system_db=self)
+                for cid in self.cursor.fetchall()
+            ]
+        else:
+            raise RuntimeError("Must give atomset or bondset.")
+
     def get_configuration(self, cid):
         """Return the specified configuration.
 
@@ -748,6 +794,10 @@ class SystemDB(CIFMixin, collections.abc.MutableMapping):
             table = self["atomset_atom"]
             table.add_attribute("atomset", coltype="int", references="atomset")
             table.add_attribute("atom", coltype="int", references="atom")
+            self.db.execute(
+                "CREATE INDEX 'idx_atomset_atom_atomset_atom' "
+                'ON atomset_atom ("atomset", "atom")'
+            )
 
             # The bonds, and sets of bonds
             table = self["bond"]
@@ -755,6 +805,10 @@ class SystemDB(CIFMixin, collections.abc.MutableMapping):
             table.add_attribute("i", coltype="int", references="atom")
             table.add_attribute("j", coltype="int", references="atom")
             table.add_attribute("bondorder", coltype="int", default=1)
+            # Only need for infinite networked systems. Think about later!
+            # table.add_attribute("offset1", coltype="int", default=0)
+            # table.add_attribute("offset2", coltype="int", default=0)
+            # table.add_attribute("offset3", coltype="int", default=0)
 
             table = self["bondset"]
             table.add_attribute("id", coltype="int", pk=True)
@@ -762,6 +816,10 @@ class SystemDB(CIFMixin, collections.abc.MutableMapping):
             table = self["bondset_bond"]
             table.add_attribute("bondset", coltype="int", references="bondset")
             table.add_attribute("bond", coltype="int", references="bond")
+            self.db.execute(
+                "CREATE INDEX 'idx_bondset_bond_bondset_bond' "
+                'ON bondset_bond ("bondset", "bond")'
+            )
 
             # Now we can set up the configurations
             table = self["configuration"]
@@ -775,6 +833,11 @@ class SystemDB(CIFMixin, collections.abc.MutableMapping):
             table.add_attribute("cell", coltype="int", references="cell")
             table.add_attribute("atomset", coltype="int", references="atomset")
             table.add_attribute("bondset", coltype="int", references="bondset")
+            table.add_attribute("charge", coltype="int", notnull=True, default=0)
+            table.add_attribute("spin_multiplicity", coltype="int")
+            table.add_attribute("n_active_electrons", coltype="int", default=0)
+            table.add_attribute("n_active_orbitals", coltype="int", default=0)
+            table.add_attribute("state", coltype="str", default="1")
 
             # And coordinates, which depend on configurations
             table = self["coordinates"]
@@ -785,7 +848,13 @@ class SystemDB(CIFMixin, collections.abc.MutableMapping):
             table.add_attribute("x", coltype="float")
             table.add_attribute("y", coltype="float")
             table.add_attribute("z", coltype="float")
-
+            self.db.execute(
+                "CREATE INDEX 'idx_coordinates_atom' ON coordinates (\"atom\")"
+            )
+            self.db.execute(
+                "CREATE INDEX idx_coordinates_atom_configuration "
+                "    ON coordinates(atom, configuration)"
+            )
             # The definition of the subsets -- templates
             table = self["template"]
             table.add_attribute("id", coltype="int", pk=True)
@@ -807,12 +876,27 @@ class SystemDB(CIFMixin, collections.abc.MutableMapping):
                 "configuration", coltype="int", references="configuration"
             )
             table.add_attribute("template", coltype="int", references="template")
+            self.db.execute(
+                "CREATE INDEX subset_idx_template_configuration "
+                "ON subset(template, configuration)"
+            )
 
             # The connection between subsets and the atoms in the system
             table = self["subset_atom"]
             table.add_attribute("atom", coltype="int", references="atom")
             table.add_attribute("subset", coltype="int", references="subset")
             table.add_attribute("templateatom", coltype="int", references="atom")
+            self.db.execute(
+                "CREATE INDEX 'idx_subset_atom_subset_atom' "
+                'ON subset_atom ("subset", "atom")'
+            )
+
+            #####################################################
+            # The star schema for storing properties and features
+            #####################################################
+
+            properties = self.properties
+            properties.create_schema()
 
             self.db.commit()
 
